searchData={"items":[{"type":"module","title":"Supex","doc":"[![Hex.pm](https://img.shields.io/hexpm/v/supex.svg)](https://hex.pm/packages/supex)\n[![API docs](https://img.shields.io/hexpm/v/supex.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/supex)\n[![Hex Downloads](https://img.shields.io/hexpm/dt/supex)](https://hex.pm/packages/supex)\n[![Last Updated](https://img.shields.io/github/last-commit/alexisruccius/supex.svg)](https://github.com/alexisruccius/supex/commits/master)\n[![GitHub stars](https://img.shields.io/github/stars/alexisruccius/supex.svg)](https://github.com/alexisruccius/supex/stargazers)\n\nSupex = SuperCollider + Elixir\n\nAn Elixir wrapper for the music live-coding language SuperCollider.\nSupex communicates with SuperCollider's `sclang` tool, letting you generate and control sound directly from Elixir.\n\n- 🎧 Play basic oscillators with a clean, pipeable syntax\n- 🔤 Send raw SuperCollider code when needed\n- ⛔ Stop sounds by name\n\nBuilt for musicians, coders, and live performers who want to use Elixir for audio synthesis.","ref":"Supex.html"},{"type":"module","title":"Installation - Supex","doc":"The package can be installed by adding `supex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:supex, \"~> 0.2.0\"}\n]\nend\n```\n\n> #### Note on v0.2.0 {: .tip}\n> The library is now fully refactored with a clear structure and consistent naming.\n> The sound naming issue in v0.1.0 has been fixed.\n\n> #### ⚙ Requires `sclang` to be installed {: .info}\n> Install with `sudo apt install supercollider-language` or `sudo apt install supercollider` on Ubuntu.\n> For all platforms, see [SuperCollider's installation guide](https://supercollider.github.io/downloads.html).\n\n## 🔍 Learn SuperCollider basics\n\nhttps://doc.sccode.org/Tutorials/Getting-Started/00-Getting-Started-With-SC.html\n\n## 🟢 Start the SuperCollider sclang server\n\n```elixir\niex> Supex.Sclang.start_link(:ok)\n```\n\n## 💡 Examples\n\n▶ Play a sine oscillator at 269 Hz and name it \"y\", pan to center; then stop it:\n\n```elixir\niex> import Supex\niex> sin() |> freq(269) |> pan |> play(\"y\")\niex> stop(\"y\")\n```\n\n▶ Modulate volume of a sine wave using another sine as LFO:\n\n```elixir\niex> import Supex\niex> sin() |> mul(sin() |> freq(2) |> mul(0.4) |> add(0.5) |> lfo) |> pan |> play\niex> stop()\n```\n\n▶ Modulate a pulse wave's frequency and width:\n\n```elixir\niex> import Supex\niex> pulse() |> freq(saw() |> freq(0.1) |> mul(100) |> add(100) |> lfo) |> width(sin() |> freq(6) |> mul(0.5) |> add(0.5) |> lfo) |> pan |> play\niex> stop()\n```\n\n🔤 Send a raw SuperCollider expression:\n\n```elixir\niex> import Supex\niex> \"RLPF.ar(Pulse.ar([100, 250], 0.5, 0.1), XLine.kr(8000, 400, 5), 0.05)\" |> pan |> play\niex> stop()\n```\nor\n\n```elixir\niex> import Supex\niex> execute(\"play{LFCub.ar(LFSaw.kr(LFPulse.kr(1/4,1/4,1/4)*2+2,1,-20,50))+(WhiteNoise.ar(LFPulse.kr(4,0,LFPulse.kr(1,3/4)/4+0.05))/8)!2}\")\niex> stop()\n```\n\n## ⚠️ Disclaimer\n\nSuperCollider and Supex can produce loud, sudden sounds.\nUse volume control and a limiter to protect your ears.\nAvoid hearing damage.\n\n## 🛠️ Note\n\nSupex is in early development.\nExpect API changes.","ref":"Supex.html#module-installation"},{"type":"function","title":"Supex.add/2","doc":"Add the value to the signal.\n\nValues can be `0.1` or `1` for example.","ref":"Supex.html#add/2"},{"type":"function","title":"examples - Supex.add/2","doc":"iex> import Supex\n    iex> pulse() |> add(0.3) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#add/2-examples"},{"type":"function","title":"Supex.execute/1","doc":"Executes a raw SuperCollider command on the `sclang` server.\n\nMust be a string.","ref":"Supex.html#execute/1"},{"type":"function","title":"example - Supex.execute/1","doc":"iex> import Supex\n    iex> execute(\"play{LFCub.ar(LFSaw.kr(LFPulse.kr(1/4,1/4,1/4)*2+2,1,-20,50))+(WhiteNoise.ar(LFPulse.kr(4,0,LFPulse.kr(1,3/4)/4+0.05))/8)!2}\")\n    iex> stop()","ref":"Supex.html#execute/1-example"},{"type":"function","title":"Supex.freq/2","doc":"Tune the frequency of an oscillator.","ref":"Supex.html#freq/2"},{"type":"function","title":"examples - Supex.freq/2","doc":"iex> import Supex\n    iex> pulse() |> freq(369) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#freq/2-examples"},{"type":"function","title":"Supex.level/2","doc":"Sets the output level.","ref":"Supex.html#level/2"},{"type":"function","title":"example - Supex.level/2","doc":"iex> import Supex\n    iex> sin() |> freq(269) |> pan |> level(0.5) |> play","ref":"Supex.html#level/2-example"},{"type":"function","title":"Supex.lfo/1","doc":"Transforms a \"normal\" oscillator to a LFO to use it as a modulator.\n\nIt uses `kr` (control rate) instead of `ar`(audio rate),\ncf. https://doc.sccode.org/Tutorials/Getting-Started/05-Functions-and-Sound.html","ref":"Supex.html#lfo/1"},{"type":"function","title":"examples - Supex.lfo/1","doc":"Modulate the volume of a sine wave with another sine wave as an LFO:\n\n    iex> import Supex\n    iex> sin() |> mul(sin() |> freq(3) |> mul(0.5) |> add(0.5) |> lfo) |> pan |> play\n    iex> stop()\n\n    iex> import Supex\n    iex> pulse() |> mul(sin() |> freq(2) |> mul(0.4) |> add(0.5) |> lfo) |> freq(saw() |> freq(0.2) |> mul(100) |> add(100) |> lfo) |> pan |> play\n    iex> stop()","ref":"Supex.html#lfo/1-examples"},{"type":"function","title":"Supex.mul/2","doc":"Multiplication of the signal.\n\nChoose values between `0.1` and `1` for not hurting your ears.","ref":"Supex.html#mul/2"},{"type":"function","title":"examples - Supex.mul/2","doc":"iex> import Supex\n    iex> pulse() |> mul(0.2) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#mul/2-examples"},{"type":"function","title":"Supex.osc/0","doc":"Create an oscillator.\n\n`type` can be:\n\n  `:sin` (sinus wave)\n  `:saw` (saw wave)\n  `:pulse` (pulse wave, aka square wave)\n\nDefaults to `:sin`.","ref":"Supex.html#osc/0"},{"type":"function","title":"Supex.osc/1","doc":"","ref":"Supex.html#osc/1"},{"type":"function","title":"Supex.pan/1","doc":"Pans the mono signal in the stereo spectrum.\n\nDefaults to centering the signal.\n\nUse `pos/2` for panning the position (-1.0 = left, 0 = center, 1.0 = right).\n\nUse `level/2` for scaling the output level.","ref":"Supex.html#pan/1"},{"type":"function","title":"example - Supex.pan/1","doc":"iex> import Supex\n    iex> sin() |> freq(269) |> pan |> pos(0.69) |> play","ref":"Supex.html#pan/1-example"},{"type":"function","title":"Supex.phase/2","doc":"The phase of a sinus wave.","ref":"Supex.html#phase/2"},{"type":"function","title":"examples - Supex.phase/2","doc":"iex> import Supex\n    iex> saw() |> freq(369) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#phase/2-examples"},{"type":"function","title":"Supex.play/1","doc":"Play the composed oscillator, or a raw SuperCollider's command (as a string).\n\nBy default, the SuperCollider command will be referenced with the variable \"x\".\nFor example, you can stop playing it with `stop(\"x\")`","ref":"Supex.html#play/1"},{"type":"function","title":"example - Supex.play/1","doc":"iex> import Supex\n    iex> sin() |> freq(269) |> play","ref":"Supex.html#play/1-example"},{"type":"function","title":"Supex.play/2","doc":"Play the composed oscillator, or a raw SuperCollider's command (as a string),\nand naming it for referencing.\n\nThe SuperCollider command will be referenced with the given name.\nYou can stop it using `stop/1`.\n\nWhile SuperCollider only accepts single characters as global variables (e.g., \"x\", \"y\", \"z\"),\nlonger names can be used as environment variables and will be declared accordingly.","ref":"Supex.html#play/2"},{"type":"function","title":"examples - Supex.play/2","doc":"iex> import Supex\n    iex> sin() |> freq(269) |> pan |> play(\"y\")\n    iex> stop(\"y\")\n\n    iex> import Supex\n    iex> pulse() |> freq(269) |> pan |> play(\"sound\")\n    iex> stop(\"sound\")","ref":"Supex.html#play/2-examples"},{"type":"function","title":"Supex.pos/2","doc":"Pan position -1.0 = left, 0 = center, 1.0 = right","ref":"Supex.html#pos/2"},{"type":"function","title":"example - Supex.pos/2","doc":"Pan a sound slightly to the right:\n\n    iex> import Supex\n    iex> sin() |> freq(269) |> pan |> pos(0.69) |> play","ref":"Supex.html#pos/2-example"},{"type":"function","title":"Supex.pulse/0","doc":"Create a pulse oscillator.\n\nUses the SuperCollider Pulse wave generator,\nsee https://doc.sccode.org/Classes/Pulse.html\n\n`freq` frequency in Hertz,\n\n`width` pulse width ratio from zero to one (0.5 makes a square wave)\n\n`mul` output will be multiplied by this value,\n\n`add` this value will be added to the output.\n\nFor setting these values use `freq/2`, `width/2`, `mul/2`, `add/2`, and `lfo/1`.","ref":"Supex.html#pulse/0"},{"type":"function","title":"examples - Supex.pulse/0","doc":"iex> import Supex\n    iex> pulse() |> pan |> play\n    iex> stop(\"x\")\n\n    iex> import Supex\n    iex> pulse() |> freq(369) |> width(0.6) |> mul(0.2) |> add(0.3) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#pulse/0-examples"},{"type":"function","title":"Supex.saw/0","doc":"Create a saw oscillator.\n\nUses the SuperCollider Saw wave generator,\nsee https://doc.sccode.org/Classes/Saw.html\n\n`freq` frequency in Hertz,\n\n`mul` output will be multiplied by this value,\n\n`add` this value will be added to the output.\n\nFor setting these values use `freq/2`, `mul/2`, `add/2`, and `lfo/1`.","ref":"Supex.html#saw/0"},{"type":"function","title":"example - Supex.saw/0","doc":"iex> import Supex\n    iex> saw() |> pan |> play\n    iex> stop(\"x\")\n\n    iex> import Supex\n    iex> saw() |> freq(369) |> mul(0.2) |> add(0.3) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#saw/0-example"},{"type":"function","title":"Supex.sin/0","doc":"Creates a sine oscillator.\n\nUses the SuperCollider SinOsc sine wave generator,\nsee https://doc.sccode.org/Classes/SinOsc.html\n\n`freq` frequency in Hertz,\n\n`phase`\tphase in radians (should be within the range +-8pi),\n\n`mul` output will be multiplied by this value,\n\n`add` this value will be added to the output.\n\nFor setting these values use `freq/2`, `phase/2`, `mul/2`, `add/2`, and `lfo/1`.","ref":"Supex.html#sin/0"},{"type":"function","title":"examples - Supex.sin/0","doc":"iex> import Supex\n    iex> sin() |> pan |> play\n    iex> stop(\"x\")\n\n    iex> import Supex\n    iex> sin() |> freq(369) |> phase(0.1) |> mul(0.2) |> add(0.3) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#sin/0-examples"},{"type":"function","title":"Supex.stop/0","doc":"Stop playing all SuperCollider sounds.\n\nUse `stop/1` to stop sound named with `play/2`.","ref":"Supex.html#stop/0"},{"type":"function","title":"example - Supex.stop/0","doc":"iex> import Supex\n    iex> sin() |> pan |> play()\n    iex> pulse() |> pan |> play()\n    iex> stop()","ref":"Supex.html#stop/0-example"},{"type":"function","title":"Supex.stop/1","doc":"Stop playing a SuperCollider command by name.\n\n`play/1` defaults to `\"x\"`.\n\nUse `play/2` to set a name.","ref":"Supex.html#stop/1"},{"type":"function","title":"example - Supex.stop/1","doc":"iex> import Supex\n    iex> sin() |> pan |> play()\n    iex> stop(\"x\")\n\n    iex> import Supex\n    iex> sin() |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#stop/1-example"},{"type":"function","title":"Supex.stop_playing/0","doc":"Stops all sound playing.","ref":"Supex.html#stop_playing/0"},{"type":"function","title":"Supex.width/2","doc":"The pulse width of a pulse wave oscillator.\n\n`width` should be a value between `0.01` and `0.99`.","ref":"Supex.html#width/2"},{"type":"function","title":"examples - Supex.width/2","doc":"iex> import Supex\n    iex> pulse() |> width(0.6) |> pan |> play(\"y\")\n    iex> stop(\"y\")","ref":"Supex.html#width/2-examples"},{"type":"module","title":"Supex.Command","doc":"Module for SuperCollider commands rendering.","ref":"Supex.Command.html"},{"type":"function","title":"Supex.Command.build/1","doc":"Builds the SuperCollider command from a ugen struct.","ref":"Supex.Command.html#build/1"},{"type":"function","title":"Supex.Command.play/1","doc":"Adding play to the sc_command.\n\nBy default, the SuperCollider command will be referenced with the variable \"x\".\nFor example, you can stop playing it with `stop(\"x\")`","ref":"Supex.Command.html#play/1"},{"type":"function","title":"Supex.Command.play/2","doc":"Adding play to the sc_command, and naming it for referencing.\n\nThe SuperCollider command will be referenced with the given name.\nYou can stop it using `stop(\" \")`.\n\nWhile SuperCollider only accepts single characters as global variables (e.g., \"y\", \"i\"),\nlonger names can be used as environment variables and will be declared accordingly.","ref":"Supex.Command.html#play/2"},{"type":"function","title":"Supex.Command.stop/1","doc":"Command for stopping sound playing referenced by name.","ref":"Supex.Command.html#stop/1"},{"type":"module","title":"Supex.Sclang","doc":"Starts the port for SuperCollider's `sclang` and\nsends SuperCollider's commands to this `sclang` port.","ref":"Supex.Sclang.html"},{"type":"function","title":"Supex.Sclang.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Supex.Sclang.html#child_spec/1"},{"type":"function","title":"Supex.Sclang.close_port/0","doc":"","ref":"Supex.Sclang.html#close_port/0"},{"type":"function","title":"Supex.Sclang.execute/1","doc":"","ref":"Supex.Sclang.html#execute/1"},{"type":"function","title":"Supex.Sclang.start_link/1","doc":"Starts `sclang` via a port,\nand boots the SuperCollider server.","ref":"Supex.Sclang.html#start_link/1"},{"type":"function","title":"Supex.Sclang.stop_playing/0","doc":"","ref":"Supex.Sclang.html#stop_playing/0"},{"type":"module","title":"Supex.Sclang.ScPort","doc":"Port to the SuperCollider's command line tool `sclang`.","ref":"Supex.Sclang.ScPort.html"},{"type":"function","title":"Supex.Sclang.ScPort.close/1","doc":"","ref":"Supex.Sclang.ScPort.html#close/1"},{"type":"function","title":"Supex.Sclang.ScPort.open/0","doc":"Opens a port to SC's `sclang.`","ref":"Supex.Sclang.ScPort.html#open/0"},{"type":"function","title":"Supex.Sclang.ScPort.send_sc_command/2","doc":"Sends a SuperCollider's command to the `sclang` via the port.","ref":"Supex.Sclang.ScPort.html#send_sc_command/2"},{"type":"module","title":"Supex.Sclang.ScServer","doc":"Commands for a SC server, like booting or stop playing all sounds.","ref":"Supex.Sclang.ScServer.html"},{"type":"function","title":"Supex.Sclang.ScServer.boot/0","doc":"","ref":"Supex.Sclang.ScServer.html#boot/0"},{"type":"function","title":"Supex.Sclang.ScServer.booted/1","doc":"","ref":"Supex.Sclang.ScServer.html#booted/1"},{"type":"function","title":"Supex.Sclang.ScServer.stop_playing/0","doc":"","ref":"Supex.Sclang.ScServer.html#stop_playing/0"},{"type":"module","title":"Supex.Ugen","doc":"For composing Oscillators and other SuperCollider's UGens (UnitGnerators).","ref":"Supex.Ugen.html"},{"type":"module","title":"examples - Supex.Ugen","doc":"iex> import Supex.Ugen\niex> sin() |> freq(690) |> phase(6) |> mul(0.9) |> add(0.69)\n%Supex.Ugen.SinOsc{add: 0.69, phase: 6, freq: 690, mul: 0.9}","ref":"Supex.Ugen.html#module-examples"},{"type":"function","title":"Supex.Ugen.add/2","doc":"","ref":"Supex.Ugen.html#add/2"},{"type":"function","title":"Supex.Ugen.freq/2","doc":"","ref":"Supex.Ugen.html#freq/2"},{"type":"function","title":"Supex.Ugen.level/2","doc":"","ref":"Supex.Ugen.html#level/2"},{"type":"function","title":"Supex.Ugen.lfo/1","doc":"Transforms a \"normal\" oscillator to a LFO.\n\nIt uses `kr` (control rate) instead of `ar`(audio rate),\ncf. https://doc.sccode.org/Tutorials/Getting-Started/05-Functions-and-Sound.html","ref":"Supex.Ugen.html#lfo/1"},{"type":"function","title":"Supex.Ugen.mul/2","doc":"","ref":"Supex.Ugen.html#mul/2"},{"type":"function","title":"Supex.Ugen.pan/1","doc":"","ref":"Supex.Ugen.html#pan/1"},{"type":"function","title":"Supex.Ugen.phase/2","doc":"","ref":"Supex.Ugen.html#phase/2"},{"type":"function","title":"Supex.Ugen.pos/2","doc":"","ref":"Supex.Ugen.html#pos/2"},{"type":"function","title":"Supex.Ugen.pulse/0","doc":"Create a pulse oscillator.","ref":"Supex.Ugen.html#pulse/0"},{"type":"function","title":"Supex.Ugen.saw/0","doc":"Create a saw oscillator.","ref":"Supex.Ugen.html#saw/0"},{"type":"function","title":"Supex.Ugen.sin/0","doc":"Create a sine oscillator.","ref":"Supex.Ugen.html#sin/0"},{"type":"function","title":"Supex.Ugen.width/2","doc":"","ref":"Supex.Ugen.html#width/2"},{"type":"module","title":"Supex.Ugen.Pan2","doc":"Module for the SuperCollider Pan2 panning unit,\nsee https://doc.sccode.org/Classes/Pan2.html\n\nDefines a `%Pan2{}` struct with:\n\n- `in`: input signal (usually a string expression)\n- `pos`: pan position (-1.0 = left, 0 = center, 1.0 = right), defaults to center.\n- `level`: output level scaling","ref":"Supex.Ugen.Pan2.html"},{"type":"function","title":"Supex.Ugen.Pan2.command/1","doc":"Builds the SuperCollider command from the `%Pan2{}` struct.","ref":"Supex.Ugen.Pan2.html#command/1"},{"type":"function","title":"Examples - Supex.Ugen.Pan2.command/1","doc":"iex> %Pan2{in: \"SinOsc.ar(440)\", pos: 0.5, level: 1.0, lfo: false}\n    \"Pan2.ar(SinOsc.ar(440), pos: 0.5, level: 1.0);\"\n\n    iex> %Pan2{in: \"SinOsc.kr(2)\", pos: -0.5, level: 0.8, lfo: true}\n    \"Pan2.kr(SinOsc.kr(2), pos: -0.5, level: 0.8);\"","ref":"Supex.Ugen.Pan2.html#command/1-examples"},{"type":"module","title":"Supex.Ugen.Pulse","doc":"Module for the SuperCollider Pulse wave generator,\nsee https://doc.sccode.org/Classes/Pulse.html\n\nDefines a `%Pulse{}` struct with\n\n`freq` frequency in Hertz,\n\n`width` pulse width ratio from zero to one (0.5 makes a square wave)\n\n`mul` output will be multiplied by this value,\n\n`add` this value will be added to the output.","ref":"Supex.Ugen.Pulse.html"},{"type":"function","title":"Supex.Ugen.Pulse.command/1","doc":"Builds the SuperCollider command from the `%Pulse{}` struct.","ref":"Supex.Ugen.Pulse.html#command/1"},{"type":"function","title":"example - Supex.Ugen.Pulse.command/1","doc":"iex> %Pulse{freq: 440, width: 0, mul: 0.1, add: 0, lfo: false}\n\"Pulse.ar(freq: 440, width: 0, mul: 0.1, add: 0);\"\n\niex> %Pulse{freq: 440, width: 0, mul: 0.1, add: 0, lfo: true}\n\"Pulse.kr(freq: 440, width: 0, mul: 0.1, add: 0);\"","ref":"Supex.Ugen.Pulse.html#command/1-example"},{"type":"module","title":"Supex.Ugen.Saw","doc":"Module for the SuperCollider Saw wave generator,\nsee https://doc.sccode.org/Classes/Saw.html\n\nDefines a `%Saw{}` struct with\n\n`freq:` frequency in Hertz,\n\n`mul` output will be multiplied by this value,\n\n`add` this value will be added to the output.","ref":"Supex.Ugen.Saw.html"},{"type":"function","title":"Supex.Ugen.Saw.command/1","doc":"Builds the SuperCollider command from the `%Saw{}` struct.","ref":"Supex.Ugen.Saw.html#command/1"},{"type":"function","title":"example - Supex.Ugen.Saw.command/1","doc":"iex> %Saw{freq: 440, mul: 0.1, add: 0, lfo: false}\n\"Saw.ar(freq: 440, mul: 0.1, add: 0);\"\n\niex> %Saw{freq: 440, mul: 0.1, add: 0, lfo: true}\n\"Saw.kr(freq: 440, mul: 0.1, add: 0);\"","ref":"Supex.Ugen.Saw.html#command/1-example"},{"type":"module","title":"Supex.Ugen.SinOsc","doc":"Module for the SuperCollider SinOsc sine wave generator,\nsee https://doc.sccode.org/Classes/SinOsc.html\n\n\nDefines a `%SinOsc{}` struct with\n\n`freq` frequency in Hertz,\n\n`phase`\tphase in radians (should be within the range +-8pi),\n\n`mul` output will be multiplied by this value,\n\n`add` this value will be added to the output.","ref":"Supex.Ugen.SinOsc.html"},{"type":"function","title":"Supex.Ugen.SinOsc.command/1","doc":"Builds the SuperCollider command from the `%SinOsc{}` struct.","ref":"Supex.Ugen.SinOsc.html#command/1"},{"type":"function","title":"example - Supex.Ugen.SinOsc.command/1","doc":"iex> %SinOsc{freq: 440, phase: 0, mul: 0.1, add: 0, lfo: false}\n\"SinOsc.ar(freq: 440, phase: 0, mul: 0.1, add: 0);\"\n\niex> %SinOsc{freq: 440, phase: 0, mul: 0.1, add: 0, lfo: true}\n\"SinOsc.kr(freq: 440, phase: 0, mul: 0.1, add: 0);\"","ref":"Supex.Ugen.SinOsc.html#command/1-example"},{"type":"extras","title":"Supex","doc":"# Supex\n\n[![Hex.pm](https://img.shields.io/hexpm/v/supex.svg)](https://hex.pm/packages/supex)\n[![API docs](https://img.shields.io/hexpm/v/supex.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/supex)\n[![Hex Downloads](https://img.shields.io/hexpm/dt/supex)](https://hex.pm/packages/supex)\n[![Last Updated](https://img.shields.io/github/last-commit/alexisruccius/supex.svg)](https://github.com/alexisruccius/supex/commits/master)\n[![GitHub stars](https://img.shields.io/github/stars/alexisruccius/supex.svg)](https://github.com/alexisruccius/supex/stargazers)\n\nSupex = SuperCollider + Elixir\n\nAn Elixir wrapper for the music live-coding language SuperCollider.\nSupex communicates with SuperCollider's `sclang` tool, letting you generate and control sound directly from Elixir.\n\n- 🎧 Play basic oscillators with a clean, pipeable syntax\n- 🔤 Send raw SuperCollider code when needed\n- ⛔ Stop sounds by name\n\nBuilt for musicians, coders, and live performers who want to use Elixir for audio synthesis.","ref":"readme.html"},{"type":"extras","title":"Installation - Supex","doc":"The package can be installed by adding `supex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:supex, \"~> 0.2.0\"}\n]\nend\n```\n\n  > #### Note on v0.2.0 {: .tip}\n  > The library is now fully refactored with a clear structure and consistent naming.  \n  > The sound naming issue in v0.1.0 has been fixed.\n\n  > #### ⚙ Requires `sclang` to be installed {: .info}\n  > Install with `sudo apt install supercollider-language` or `sudo apt install supercollider` on Ubuntu.\n  > For all platforms, see [SuperCollider's installation guide](https://supercollider.github.io/downloads.html).\n\n## 🔍 Learn SuperCollider basics\n\nhttps://doc.sccode.org/Tutorials/Getting-Started/00-Getting-Started-With-SC.html\n\n## 🟢 Start the SuperCollider sclang server\n\n```elixir\niex> Supex.Sclang.start_link(:ok)\n```\n\n## 💡 Examples\n\n▶ Play a sine oscillator at 269 Hz and name it \"y\", pan to center; then stop it:\n\n```elixir\niex> import Supex\niex> sin() |> freq(269) |> pan |> play(\"y\")\niex> stop(\"y\")\n```\n\n▶ Modulate volume of a sine wave using another sine as LFO:\n\n```elixir\niex> import Supex\niex> sin() |> mul(sin() |> freq(2) |> mul(0.4) |> add(0.5) |> lfo) |> pan |> play\niex> stop()\n```\n\n▶ Modulate a pulse wave's frequency and width:\n\n```elixir\niex> import Supex\niex> pulse() |> freq(saw() |> freq(0.1) |> mul(100) |> add(100) |> lfo) |> width(sin() |> freq(6) |> mul(0.5) |> add(0.5) |> lfo) |> pan |> play\niex> stop()\n```\n\n🔤 Send a raw SuperCollider expression:\n\n```elixir\niex> import Supex\niex> \"RLPF.ar(Pulse.ar([100, 250], 0.5, 0.1), XLine.kr(8000, 400, 5), 0.05)\" |> pan |> play\niex> stop()\n```\nor\n\n```elixir\niex> import Supex\niex> execute(\"play{LFCub.ar(LFSaw.kr(LFPulse.kr(1/4,1/4,1/4)*2+2,1,-20,50))+(WhiteNoise.ar(LFPulse.kr(4,0,LFPulse.kr(1,3/4)/4+0.05))/8)!2}\")\niex> stop()\n```\n\n## ⚠️ Disclaimer\n\nSuperCollider and Supex can produce loud, sudden sounds.\nUse volume control and a limiter to protect your ears.\nAvoid hearing damage.\n\n## 🛠️ Note\n\nSupex is in early development.\nExpect API changes.","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 (2025-07-16) - Changelog","doc":"The library is now fully refactored with a clear structure and consistent naming. The sound naming issue in v0.1.0 has been fixed.","ref":"changelog.html#v0-2-0-2025-07-16"},{"type":"extras","title":"Features - Changelog","doc":"- Add `sin/0`, `saw/0`, and `pulse/0` oscillator functions replacing `osc/1`\n- Add `pan/1` with `pos/2` and `level/2` for stereo panning control","ref":"changelog.html#features"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Refactor `Supex` for consistent syntax, naming, and improved internal structure\n- Improve documentation for all public functions","ref":"changelog.html#enhancements"},{"type":"extras","title":"Deprecations - Changelog","doc":"- Deprecate `osc/0` and `osc/1` in favor of specific oscillator functions (`sin/0`, `saw/0`, `pulse/0`)","ref":"changelog.html#deprecations"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Fix naming handling in `play/2` for multi-character names\n- Correct typespecs for oscillator modifier functions","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Remove `Synth` (`Supex.synth/0`) and `Example` modules","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Documentation - Changelog","doc":"- Update examples and README for clarity and accuracy","ref":"changelog.html#documentation"},{"type":"extras","title":"v0.1.1 (2025-07-10) - Changelog","doc":"","ref":"changelog.html#v0-1-1-2025-07-10"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Refactored `lfo/1` in `Spex` and `Ugen` modules.","ref":"changelog.html#enhancements-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Corrected typespecs in `Spex` and `Ugen` modules.","ref":"changelog.html#bug-fixes-1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}